@@ -202,21 +202,26 @@ class ModelBuilder:
             elif c['name'] == 'type':
                 found['static'] = c['attributes']["static"]
                 found.setdefault('return-value', {})
+                found['return-value'].setdefault('description', '')
                 if "type" in c['attributes']:
                     found['return-value']['type'] = c['attributes']['type']
                 else:
                     found['return-value']['type'] = 'void'
-            elif c['name'] == 'documentation' and 'attributes' in c:
-                found['description'] = c['attributes']['value']
-                if found['return-value']['type'] != 'void':
-                    found['return-value']['description'] = self._extract_return_value_description(found['description'])
+            elif c['name'] == 'documentation':
+                if 'attributes' in c:
+                    found['description'] = c['attributes']['value']
+                    if found['return-value']['type'] != 'void':
+                        found['return-value']['description'] = self._extract_return_value_description(found['name'], found['description'])
+                elif found.get('return-value', {}).get('type', 'void') != 'void':
+                    print(f"WARNING: operation {found['name']} returning non-void is missing return value description")
             elif c['name'] == 'parameters':
                 self._collect_parameters(c, found['parameters'])
 
-    def _extract_return_value_description(self, description):
+    def _extract_return_value_description(self, op_name, description):
         for line in description.split('\n'):
             if 'Return value:' in line:
                 return line.replace('Return value:', '').strip()
+        print(f"WARNING: return value of {op_name} is missing description")
         return ''
 
     def _collect_parameters(self, node:dict, params: list):
@@ -292,8 +297,11 @@ class ModelBuilder:
     def _get_includes(self, artifact, header_ref):
         for dep in self._model['dependencies']:
             if dep['client'] == artifact['xmi:id'] and dep.get('stereotype', 'include'):
-                supplier_el = self._id_map[dep['supplier']]
-                header_ref['includes'] += [ supplier_el['name'] ]
+                if dep['supplier'] in self._id_map:
+                    supplier_el = self._id_map[dep['supplier']]
+                    header_ref['includes'] += [ supplier_el['name'] ]
+                else:
+                    print(f"WARNING: artifact {dep['supplier']} not found in the model, ignoring")
 
     def _get_brief(self, descr: str):
         p_dot = descr.find('.')
@@ -328,7 +336,7 @@ class ModelBuilder:
                         f.setdefault('out-params', [])
                         f.setdefault('inout-params', [])
                         f.setdefault('return-value', { 'type': 'void', 'description': '' })
-                        f['description'] = self._clean_el_description(f['description'])
+                        f['description'] = self._clean_el_description(f.get('description', ''))
                         f['brief'] = self._get_brief(f['description'])
 
                         self._set_func_params(f)
